@@ -14,6 +14,8 @@ from .editorial import editorial
 
 from .cv import cv
 
+from .catalog import catalog
+
 from .ai_audio import ai_audio
 
 from .editor import editor
@@ -43,6 +45,8 @@ cli.add_command(editorial)
 
 cli.add_command(cv)
 
+cli.add_command(catalog)
+
 cli.add_command(ai_audio)
 
 cli.add_command(editor)
